randompasswords
===============
A simple GUI program that takes user input for keywords, minimum password length,
maximum password length, and any special characters to generate random password possibilities
derived from the input.

Installation
------------
Save the .py files under randompasswords and run it with python3. See requirements.txt for any module requirements and install them with pip
Requires python3. Check python version with

::

    python --version

If not installed, install python3 on this url https://www.python.org/downloads/


Or use pip to install randompasswords directly

::

    pip install randompasswords

Usage
-----
Run __main__.py and follow instructions on GUI window

Acknowledgment
--------------
Thank you to Brett Beekley, my mentor for encouraging me and
helping me think up this idea for a side project

License
-------
`MIT
<https://choosealicense.com/licenses/mit/>`_